@@ -656,80 +656,6 @@ impl CompiledInstruction {
     pub fn program_id<'a>(&self, program_ids: &'a [Pubkey]) -> &'a Pubkey {
         &program_ids[self.program_id_index as usize]
     }
-
-    /// Visit each unique instruction account index once
-    pub fn visit_each_account(
-        &self,
-        work: &mut dyn FnMut(usize, usize) -> Result<(), InstructionError>,
-    ) -> Result<(), InstructionError> {
-        let mut unique_index = 0;
-        'root: for (i, account_index) in self.accounts.iter().enumerate() {
-            // Note: This is an O(n^2) algorithm,
-            // but performed on a very small slice and requires no heap allocations
-            for account_index_before in self.accounts[..i].iter() {
-                if account_index_before == account_index {
-                    continue 'root; // skip dups
-                }
-            }
-            work(unique_index, *account_index as usize)?;
-            unique_index += 1;
-        }
-        Ok(())
-    }
-
-    #[cfg(not(target_arch = "bpf"))]
-    pub fn decompile(
-        &self,
-        message: &crate::message::SanitizedMessage,
-    ) -> Result<Instruction, InstructionError> {
-        Ok(Instruction::new_with_bytes(
-            *message
-                .get_account_key(self.program_id_index as usize)
-                .ok_or(InstructionError::MissingAccount)?,
-            &self.data,
-            self.accounts
-                .iter()
-                .map(|account_index| {
-                    let account_index = *account_index as usize;
-                    Ok(AccountMeta {
-                        is_signer: message.is_signer(account_index),
-                        is_writable: message.is_writable(account_index),
-                        pubkey: *message
-                            .get_account_key(account_index)
-                            .ok_or(InstructionError::MissingAccount)?,
-                    })
-                })
-                .collect::<Result<Vec<AccountMeta>, InstructionError>>()?,
-        ))
-    }
-}
-
-#[cfg(test)]
-mod test {
-    use super::*;
-
-    #[test]
-    fn test_visit_each_account() {
-        let do_work = |accounts: &[u8]| -> (usize, usize) {
-            let mut unique_total = 0;
-            let mut account_total = 0;
-            let mut work = |unique_index: usize, account_index: usize| {
-                unique_total += unique_index;
-                account_total += account_index;
-                Ok(())
-            };
-            let instruction = CompiledInstruction::new(0, &[0], accounts.to_vec());
-            instruction.visit_each_account(&mut work).unwrap();
-
-            (unique_total, account_total)
-        };
-
-        assert_eq!((6, 6), do_work(&[0, 1, 2, 3]));
-        assert_eq!((6, 6), do_work(&[0, 1, 1, 2, 3]));
-        assert_eq!((6, 6), do_work(&[0, 1, 2, 3, 3]));
-        assert_eq!((6, 6), do_work(&[0, 0, 1, 1, 2, 2, 3, 3]));
-        assert_eq!((0, 2), do_work(&[2, 2]));
-    }
 }
 
 /// Use to query and convey information about the sibling instruction components
